import React from 'react';
import { motion } from 'framer-motion';
import { MapPin, Search } from 'lucide-react';
import { Button } from './UI/Button';

interface EmptyStateProps {
  type: 'initial' | 'no-results' | 'location-error';
  message?: string;
  onAction?: () => void;
  actionLabel?: string;
}

export function EmptyState({ 
  type, 
  message, 
  onAction, 
  actionLabel 
}: EmptyStateProps) {
  const illustrations = {
    'initial': <Search className="h-16 w-16 text-muted-foreground/50" />,
    'no-results': <Search className="h-16 w-16 text-muted-foreground/50" />,
    'location-error': <MapPin className="h-16 w-16 text-muted-foreground/50" />,
  };
  
  const defaultMessages = {
    'initial': 'Share your location to discover nearby places',
    'no-results': 'No places found for your search criteria',
    'location-error': 'Unable to access your location',
  };
  
  const defaultActionLabels = {
    'initial': 'Get Started',
    'no-results': 'Clear Filters',
    'location-error': 'Try Again',
  };
  
  return (
    <motion.div
      initial={{ opacity: 0, y: 20 }}
      animate={{ opacity: 1, y: 0 }}
      transition={{ duration: 0.3 }}
      className="flex flex-col items-center justify-center p-8 text-center h-full"
    >
      <motion.div
        initial={{ scale: 0.8 }}
        animate={{ scale: 1 }}
        transition={{ delay: 0.1, duration: 0.3 }}
        className="bg-muted/30 dark:bg-muted/10 rounded-full p-6 mb-4"
      >
        {illustrations[type]}
      </motion.div>
      
      <h3 className="text-xl font-semibold mb-2">
        {type === 'initial' ? 'Welcome to AI Place Explorer' : (
          type === 'no-results' ? 'No Results Found' : 'Location Access Required'
        )}
      </h3>
      
      <p className="text-muted-foreground mb-6 max-w-md">
        {message || defaultMessages[type]}
      </p>
      
      {onAction && (
        <Button onClick={onAction}>
          {actionLabel || defaultActionLabels[type]}
        </Button>
      )}
    </motion.div>
  );
}