import React from 'react';
import { Map, Moon, Sun } from 'lucide-react';
import { Button } from './UI/Button';
import { ToggleButton } from './UI/ToggleButton';
import { motion } from 'framer-motion';
import { useTheme } from '../hooks/useTheme';

export function Header() {
  const { theme, toggleTheme } = useTheme();
  
  return (
    <header className="sticky top-0 z-10 backdrop-blur-md bg-white/70 dark:bg-gray-900/80 border-b border-gray-200 dark:border-gray-800 px-4 py-3">
      <div className="container mx-auto flex justify-between items-center">
        <motion.div 
          className="flex items-center gap-2"
          initial={{ opacity: 0, x: -20 }}
          animate={{ opacity: 1, x: 0 }}
          transition={{ duration: 0.3 }}
        >
          <Map className="h-6 w-6 text-primary" />
          <h1 className="text-xl font-bold bg-gradient-to-r from-primary to-accent bg-clip-text text-transparent">
            AI Place Explorer
          </h1>
        </motion.div>
        
        <motion.div 
          className="flex items-center gap-2"
          initial={{ opacity: 0, x: 20 }}
          animate={{ opacity: 1, x: 0 }}
          transition={{ duration: 0.3 }}
        >
          <ToggleButton
            isToggled={theme === 'dark'}
            onToggle={toggleTheme}
            label={
              <span className="sr-only">
                {theme === 'dark' ? 'Switch to light mode' : 'Switch to dark mode'}
              </span>
            }
            className="ml-2"
          />
          {theme === 'dark' ? (
            <Moon className="h-4 w-4 text-gray-400" />
          ) : (
            <Sun className="h-4 w-4 text-amber-500" />
          )}
        </motion.div>
      </div>
    </header>
  );
}