import { motion } from 'framer-motion';
import { cn } from '../../lib/utils';

interface ToggleButtonProps {
    isToggled: boolean;
    onToggle: () => void;
    label?: any;
    size?: 'sm' | 'md' | 'lg';
    className?: string;
}

const sizeClasses = {
    sm: {
        track: 'h-5 w-10',
        thumb: 'h-4 w-4',
    },
    md: {
        track: 'h-6 w-12',
        thumb: 'h-5 w-5',
    },
    lg: {
        track: 'h-7 w-14',
        thumb: 'h-6 w-6',
    },
};

export function ToggleButton({
    isToggled,
    onToggle,
    label,
    size = 'md',
    className,
}: ToggleButtonProps) {
    const { track, thumb } = sizeClasses[size];

    return (
        <div className={cn('flex items-center gap-2', className)}>
            {label && (
                <label className="text-sm font-medium cursor-pointer">{label}</label>
            )}
            <button
                type="button"
                role="switch"
                aria-checked={isToggled}
                onClick={onToggle}
                className={cn(
                    'relative rounded-full transition-colors focus-visible:outline-none focus-visible:ring-2 focus-visible:ring-ring focus-visible:ring-offset-2',
                    track,
                    isToggled
                        ? 'bg-primary'
                        : 'bg-gray-300 dark:bg-gray-600'
                )}
            >
                <motion.span
                    layout
                    transition={{ type: 'spring', stiffness: 500, damping: 30 }}
                    className={cn(
                        'block rounded-full bg-white shadow-md',
                        thumb,
                        isToggled ? 'translate-x-full' : ''
                    )}
                />
            </button>
        </div>
    );
}