import { motion } from 'framer-motion';
import { Map, ArrowRight } from 'lucide-react';
import { Button } from '../components/UI/Button';
import { useNavigate } from 'react-router-dom';


export const Home = () => {
    const navigate = useNavigate()
    return (
        <div className="max-w-4xl mx-auto py-12">
            <motion.div
                initial={{ opacity: 0, y: 20 }}
                animate={{ opacity: 1, y: 0 }}
                transition={{ duration: 0.5 }}
                className="text-center mb-12"
            >
                <div className="flex justify-center mb-6">
                    <Map className="h-16 w-16 text-[hsl(var(--primary))]" />
                </div>
                {/* <h1 className="text-4xl font-bold mb-4 bg-gradient-to-r from-[hsl(var(--primary))] to-[hsl(var(--accent))] bg-clip-text text-transparent">
                    
                </h1> */}
                <div className='text-4xl font-bold mb-4 text-white'>
                    Generate Leads with just a prompt
                </div>
                <p className="text-xl text-[hsl(var(--muted-foreground))] mb-8">
                    Discover and analyze nearby places using AI-powered location intelligence
                </p>
                <Button
                    size="lg"
                    className="text-lg px-8 py-6 rounded-full bg-[hsl(var(--primary))] text-[hsl(var(--primary-foreground))] hover:bg-[hsl(var(--primary))]/90" onClick={()=>navigate("/agent")}
                >
                    Start Exploring
                    <ArrowRight className="ml-2 h-5 w-5" />
                </Button>
            </motion.div>

            <div className="grid md:grid-cols-3 gap-8 mt-16">
                <motion.div
                    initial={{ opacity: 0, y: 20 }}
                    animate={{ opacity: 1, y: 0 }}
                    transition={{ duration: 0.5, delay: 0.2 }}
                    className="bg-white dark:bg-gray-800 p-6 rounded-lg shadow-md"
                >
                    <h3 className="text-lg font-semibold mb-2">Smart Discovery</h3>
                    <p className="text-[hsl(var(--muted-foreground))]">
                        AI agent intelligently identifies and categorizes places around your location.
                    </p>
                </motion.div>

                <motion.div
                    initial={{ opacity: 0, y: 20 }}
                    animate={{ opacity: 1, y: 0 }}
                    transition={{ duration: 0.5, delay: 0.3 }}
                    className="bg-white dark:bg-gray-800 p-6 rounded-lg shadow-md"
                >
                    <h3 className="text-lg font-semibold mb-2">Detailed Analysis</h3>
                    <p className="text-[hsl(var(--muted-foreground))]">
                        Get comprehensive information about each location, including ratings, hours, and more.
                    </p>
                </motion.div>

                <motion.div
                    initial={{ opacity: 0, y: 20 }}
                    animate={{ opacity: 1, y: 0 }}
                    transition={{ duration: 0.5, delay: 0.4 }}
                    className="bg-white dark:bg-gray-800 p-6 rounded-lg shadow-md"
                >
                    <h3 className="text-lg font-semibold mb-2">Export & Share</h3>
                    <p className="text-[hsl(var(--muted-foreground))]">
                        Download your discoveries in Excel format for further analysis and sharing.
                    </p>
                </motion.div>
            </div>
        </div>
    );
}