import { AIQueryParams, Place, PlaceCategory } from '../types';

// Mock data to simulate AI response
const mockPlaces: Place[] = [
  {
    id: '1',
    name: 'Central Park Cafe',
    category: 'cafe',
    address: '123 Park Avenue, New York, NY',
    description: 'A cozy cafe in the heart of Central Park offering organic coffee and pastries.',
    rating: 4.7,
    distance: 350,
    coordinates: { latitude: 40.7812, longitude: -73.9665 },
    openHours: '7:00 AM - 7:00 PM',
    priceLevel: 2,
    website: 'https://example.com/centralparkcafe',
    phoneNumber: '+1 212-555-0123',
    photos: [
      'https://images.pexels.com/photos/1855214/pexels-photo-1855214.jpeg',
      'https://images.pexels.com/photos/302899/pexels-photo-302899.jpeg'
    ]
  },
  {
    id: '2',
    name: 'Urban Bistro',
    category: 'restaurant',
    address: '456 Fifth Avenue, New York, NY',
    description: 'Modern bistro serving contemporary American cuisine with seasonal ingredients.',
    rating: 4.5,
    distance: 550,
    coordinates: { latitude: 40.7549, longitude: -73.9840 },
    openHours: '11:00 AM - 10:00 PM',
    priceLevel: 3,
    website: 'https://example.com/urbanbistro',
    phoneNumber: '+1 212-555-0124',
    photos: [
      'https://images.pexels.com/photos/67468/pexels-photo-67468.jpeg',
      'https://images.pexels.com/photos/262978/pexels-photo-262978.jpeg'
    ]
  },
  {
    id: '3',
    name: 'Skyline Hotel',
    category: 'hotel',
    address: '789 Broadway, New York, NY',
    description: 'Luxury boutique hotel with stunning views of the Manhattan skyline.',
    rating: 4.8,
    distance: 750,
    coordinates: { latitude: 40.7589, longitude: -73.9851 },
    openHours: 'Open 24 hours',
    priceLevel: 4,
    website: 'https://example.com/skylinehotel',
    phoneNumber: '+1 212-555-0125',
    photos: [
      'https://images.pexels.com/photos/261102/pexels-photo-261102.jpeg',
      'https://images.pexels.com/photos/271624/pexels-photo-271624.jpeg'
    ]
  },
  {
    id: '4',
    name: 'City Park',
    category: 'park',
    address: '321 Park Lane, New York, NY',
    description: 'Expansive urban park with walking trails, picnic areas, and playgrounds.',
    rating: 4.6,
    distance: 450,
    coordinates: { latitude: 40.7729, longitude: -73.9732 },
    website: 'https://example.com/citypark',
    phoneNumber: '+1 212-555-0126',
    photos: [
      'https://images.pexels.com/photos/1108701/pexels-photo-1108701.jpeg',
      'https://images.pexels.com/photos/863963/pexels-photo-863963.jpeg'
    ]
  },
  {
    id: '5',
    name: 'Fashion Outlet',
    category: 'store',
    address: '654 Shopping Avenue, New York, NY',
    description: 'Premium fashion outlet featuring designer brands at discounted prices.',
    rating: 4.2,
    distance: 900,
    coordinates: { latitude: 40.7539, longitude: -73.9910 },
    openHours: '10:00 AM - 9:00 PM',
    priceLevel: 3,
    website: 'https://example.com/fashionoutlet',
    phoneNumber: '+1 212-555-0127',
    photos: [
      'https://images.pexels.com/photos/331990/pexels-photo-331990.jpeg',
      'https://images.pexels.com/photos/1488463/pexels-photo-1488463.jpeg'
    ]
  },
  {
    id: '6',
    name: 'Downtown Fitness Center',
    category: 'gym',
    address: '987 Health Street, New York, NY',
    description: 'Full-service fitness center with state-of-the-art equipment and classes.',
    rating: 4.4,
    distance: 650,
    coordinates: { latitude: 40.7509, longitude: -73.9780 },
    openHours: '5:00 AM - 11:00 PM',
    priceLevel: 2,
    website: 'https://example.com/downtownfitness',
    phoneNumber: '+1 212-555-0128',
    photos: [
      'https://images.pexels.com/photos/1954524/pexels-photo-1954524.jpeg',
      'https://images.pexels.com/photos/4162487/pexels-photo-4162487.jpeg'
    ]
  },
  {
    id: '7',
    name: 'Historic Museum',
    category: 'attraction',
    address: '135 History Lane, New York, NY',
    description: 'Museum showcasing the rich history and cultural heritage of the city.',
    rating: 4.7,
    distance: 1200,
    coordinates: { latitude: 40.7713, longitude: -73.9740 },
    openHours: '9:00 AM - 5:00 PM',
    priceLevel: 2,
    website: 'https://example.com/historicmuseum',
    phoneNumber: '+1 212-555-0129',
    photos: [
      'https://images.pexels.com/photos/2372978/pexels-photo-2372978.jpeg',
      'https://images.pexels.com/photos/2570063/pexels-photo-2570063.jpeg'
    ]
  },
  {
    id: '8',
    name: 'Riverside Bar & Lounge',
    category: 'bar',
    address: '246 River Street, New York, NY',
    description: 'Upscale bar with craft cocktails and panoramic river views.',
    rating: 4.3,
    distance: 1400,
    coordinates: { latitude: 40.7623, longitude: -73.9836 },
    openHours: '4:00 PM - 2:00 AM',
    priceLevel: 3,
    website: 'https://example.com/riversidebar',
    phoneNumber: '+1 212-555-0130',
    photos: [
      'https://images.pexels.com/photos/274192/pexels-photo-274192.jpeg',
      'https://images.pexels.com/photos/1267696/pexels-photo-1267696.jpeg'
    ]
  }
];

// Simulates an AI call with random delay (300-1500ms)
function simulateAiProcessing<T>(data: T): Promise<T> {
  const delay = Math.floor(Math.random() * 1200) + 300;
  return new Promise(resolve => setTimeout(() => resolve(data), delay));
}

// Filter places based on query parameters
function filterPlaces(params: AIQueryParams): Place[] {
  let filtered = [...mockPlaces];
  
  // Adjust distances based on user location
  filtered = filtered.map(place => ({
    ...place,
    distance: Math.floor(Math.random() * params.radius * 0.8) + 100 // Random distance within radius
  }));
  
  // Filter by category if specified
  if (params.categories && params.categories.length > 0) {
    filtered = filtered.filter(place => 
      params.categories?.includes(place.category as PlaceCategory)
    );
  }
  
  // Filter by radius
  filtered = filtered.filter(place => place.distance <= params.radius);
  
  // Apply limit if specified
  if (params.limit && params.limit > 0 && params.limit < filtered.length) {
    filtered = filtered.slice(0, params.limit);
  }
  
  // Sort by distance
  return filtered.sort((a, b) => a.distance - b.distance);
}

export async function fetchNearbyPlaces(params: AIQueryParams): Promise<Place[]> {
  console.log('Fetching places with params:', params);
  
  // Filter places based on query parameters
  const filteredPlaces = filterPlaces(params);
  
  // Simulate AI processing delay
  return simulateAiProcessing(filteredPlaces);
}